@@ -203,7 +203,7 @@ buffer_erase (Buffer *buffer, int pos, int len)
 		 buffer->_len  - (pos + len));
 	
 	buffer->_len  -= len;
-	buffer->_data = realloc (buffer->_data, buffer->_len);
+	//buffer->_data = realloc (buffer->_data, buffer->_len);
 	
 	return buffer->_len;
 }
@@ -233,6 +233,10 @@ buffer_find_offset (const Buffer *buffer, int offset, const char* pattern, int l
 		if (match && (j == len)) 
 			break;
 	}
+	
+	if ( i == buffer->_len - len)
+		i = buffer_end(buffer);
+	
 	return i;
 }
 
