@@ -49,17 +49,15 @@ static const char* VANDALE_PORT   = "80";
 "q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;" \
 "q=0.2,text/css,*/*;q=0.1\r\n" \
 "Accept-Language: nl, en\r\n" \
-"Accept-Charset: ISO-8859-1\r\n" \
-"Keep-Alive: 300\r\n" \
-"Connection: keep-alive\r\n" \
-"Referer: http://www.vandale.nl/opzoeken/woordenboek/?zoekwoord=%s\r\n" \
+"Accept-Charset: UTF-8\r\n" \
+"Referer: http://www.vandale.nl/vandale/opzoeken/woordenboek/?zoekwoord=%s\r\n" \
 "\r\n"
 
 #define HTTP_REQUEST \
-"GET /opzoeken/woordenboek/?zoekwoord=%s HTTP/1.1\r\n" HTTP_HEADERS
+"GET /vandale/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.0\r\n" HTTP_HEADERS
 
 #define HTTP_REQUEST_PROXY \
-"GET http://www.vandale.nl/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.1\r\n" HTTP_HEADERS
+"GET http://www.vandale.nl/vandale/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.0\r\n" HTTP_HEADERS
 
 static char* HTTP_PROXY_HOST      = NULL;
 static char* HTTP_PROXY_PORT      = NULL;
@@ -72,7 +70,7 @@ static char*              vd_construct_http_query (const char *search_term, VDEr
 static int	          vd_perform_http_query   (int sock, char *query, VDError *ex);
 static char*              vd_get_http_results     (int sock, size_t *bytes_read, 
 						   VDCallback vd_callback, 
-					           size_t chunk_size, VDError *ex);
+					           /*size_t chunk_size,*/ VDError *ex);
 static void               vd_filter_http_buffer   (Buffer *buffer, VDError *ex);
 static void               vd_parse_http_proxy     (const char* http_proxy, char **host, 
 						   char **port, VDError *ex);
@@ -173,7 +171,7 @@ vd_query_search_term (const VDQuery *vd_query)
 void
 vd_query_perform (const VDQuery *vd_query, VDError *ex)
 {
-	vd_query_perform_progressive (vd_query, NULL, 0, ex);
+	vd_query_perform_progressive (vd_query, NULL, ex);
 }
 
 
@@ -181,7 +179,7 @@ vd_query_perform (const VDQuery *vd_query, VDError *ex)
 
 void
 vd_query_perform_progressive (const VDQuery *vd_query, VDCallback call_back,
-			      int chunk_size, VDError *ex)
+			      VDError *ex)
 {
 	int sock = -1;
 	struct addrinfo *ai, *aip;
@@ -239,7 +237,7 @@ vd_query_perform_progressive (const VDQuery *vd_query, VDCallback call_back,
 	}
 
 	result = vd_get_http_results (sock, &bytes_read, 
-			              call_back, chunk_size, ex);
+			              call_back, ex);
 	if (!result) 
 		*ex = VD_ERR_HTTP;
 	else {
@@ -299,9 +297,28 @@ vd_socket_to_site (const struct addrinfo *dest_sa, VDError *ex)
 static char*
 vd_construct_http_query (const char *search_term, VDError *ex)
 {
-	char *query;
-	int len= strlen(HTTP_PROXY_HOST ? HTTP_REQUEST_PROXY : HTTP_REQUEST) + 
-		strlen(search_term) * 2;
+	char *query, *encoded_search_term, *pos;
+	int len, i;
+
+	/* The worst that can happen is that all chars need encoding */
+	encoded_search_term = 
+	    (char *) malloc((3 * strlen(search_term) + 1) * sizeof(char));
+	pos = encoded_search_term;
+
+	if (!pos) {
+		*ex = VD_ERR_MEM;
+		return NULL;
+	}
+
+	for (i=0; i<strlen(search_term); i++) 
+		if (isalnum(search_term[i])) 
+			*(pos++) = search_term[i];
+		 else 
+			pos += sprintf(pos, "%%%2x", search_term[i]);
+	*pos = 0;
+	
+	len = strlen(HTTP_PROXY_HOST ? HTTP_REQUEST_PROXY : HTTP_REQUEST) + 
+		strlen(encoded_search_term) * 2;
 	
 	query = (char*) malloc (len + 1);
 	if (!query) {
@@ -310,8 +327,10 @@ vd_construct_http_query (const char *search_term, VDError *ex)
 	}	
 	
 	snprintf (query, len, (HTTP_PROXY_HOST ? HTTP_REQUEST_PROXY : HTTP_REQUEST),
-		  search_term,search_term);
-	
+		  encoded_search_term,encoded_search_term);
+
+	free(encoded_search_term);
+
 	return query;
 }
 
@@ -326,7 +345,7 @@ vd_perform_http_query (int sock, char *query, VDError *ex)
 
 static char*
 vd_get_http_results (int sock, size_t *bytes_read, 
-		     VDCallback vd_callback, size_t chunk_size_ /*FIXME*/,
+		     VDCallback vd_callback, /*size_t chunk_size*/ /*FIXME*/
 		     VDError *ex)
 {
 	const int max_buf    = 50000;
@@ -362,52 +381,47 @@ vd_get_http_results (int sock, size_t *bytes_read,
 }
 
 
+
 static void
 vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 {
 	const size_t min_length = 100;
 
 	int pos;
-	char *data;
 	
-	static const char* big         = "<BIG>";
-	static const char* opnieuw     = "Opnieuw/verfijnd zoeken";
-	static const char* unavailable = "onderhoudswerkzaamheden";
-
+	static const char* word        = "<span class=\"g1v\">";
+	static const char* notfound    = "Geen resultaat.";
+	static const char* metanav     = "<div class=\"metaNav\">";
+	
 	assert (http_buffer);
 	assert (ex);
 	
-	pos = buffer_find (http_buffer, big, strlen(big));
+	pos = buffer_find (http_buffer, word, strlen(word));
 	if (pos <  buffer_end (http_buffer)) {
 		buffer_erase (http_buffer, 0, pos);
 	} else {
 		/* nothing was found or not available*/
-		pos = buffer_find (http_buffer, unavailable, strlen(unavailable));
+		pos = buffer_find (http_buffer, notfound, strlen(notfound));
 		if (pos < buffer_end (http_buffer)) 
-			*ex = VD_ERR_UNAVAILABLE;
-		else
 			*ex = VD_ERR_NOT_FOUND;
+		else
+			*ex = VD_ERR_UNAVAILABLE;
 		return;
 	}
-		
-	pos = buffer_find (http_buffer, opnieuw, strlen(opnieuw));
-	if (pos != buffer_end(http_buffer))
-		buffer_erase (http_buffer, pos, buffer_length(http_buffer) - pos - 1);
 
-	/* strip extra space */
-	pos = buffer_length (http_buffer) - 1;
-	if (pos <= 0) {
-		*ex = VD_ERR_NOT_FOUND;
-		return;
-	}
-	data = (char*) buffer_data (http_buffer);
-	
-	for (--pos; pos; --pos) 
-		if (!isspace(data[pos]))
+	/* cut trailing stuff */
+	pos = buffer_find (http_buffer, metanav, strlen(metanav));
+	if (pos < buffer_end (http_buffer))
+		buffer_erase (http_buffer, pos, buffer_end(http_buffer) - pos);
+
+	/* find the last non-blank */
+	for (pos = buffer_end(http_buffer) - 1; pos >= buffer_begin(http_buffer); --pos) {
+		char c = buffer_at (http_buffer, pos);
+		if (isalnum(c))
 			break;
-
-	buffer_erase (http_buffer, pos + 1, 
-		      buffer_length (http_buffer) - pos - 2);
+	}
+	if (pos != buffer_begin(http_buffer) && pos < buffer_end(http_buffer))
+		buffer_erase (http_buffer, pos, buffer_end(http_buffer) - pos);
 	
 	if (buffer_length (http_buffer) < min_length)
 		*ex = VD_ERR_NOT_FOUND;
