@@ -114,7 +114,6 @@ void   vd_query_perform (const VDQuery *vd_query, VDError *ex);
  * vd_query: a vd query
  * callback:    callback function to call after reading @chunk_size bytes
  *		or WOULDBLOCK
- * chunk_size: number of bytes to read at a time before calling @callback
  *
  * ex      : a vd exception, receiving error information
  *
@@ -125,7 +124,6 @@ void   vd_query_perform (const VDQuery *vd_query, VDError *ex);
  */
 void     vd_query_perform_progressive (const VDQuery *vd_query, 
 				       VDCallback callback,
-				       int chunk_size,
 				       VDError *ex);
 
 
